@@ -1,4 +1,5 @@
 # https://stackoverflow.com/questions/4902974/python-import-subpackage-from-a-package-not-working
 from traquitanas.geo import converts, layers
+from traquitanas.net import downloads
 
-__all__ = ['geo', 'converts', 'layers']
+__all__ = ['geo', 'converts', 'layers', 'downloads']
